dmbc_fit object.Subsetting a dmbc_fit object.
# S4 method for dmbc_fit
subset(x, pars = character(), regex_pars = character(), ...)An object of class dmbc_fit.
An optional character vector of parameter names. If neither
pars nor regex_pars is specified, the default is to use all
parameters.
An optional regular expression to use
for parameter selection. Can be specified instead of pars or in addition
to pars.
Further arguments to pass on (currently ignored).